# sample-python-package
# This is a basic Python module and you can simply add this by using this command.

pip install kcalculator or pip3 install kcalculator

#Note:-

# It basicly perform on addition, subtraction, multiply or divide operations.
# for Now it perform only basic operation.
How to you use:
1 -> from calc import calc

2 -> calc.add_numbers(1,2)
